import logging
import requests
import os
import shutil

logger = logging.getLogger(__name__)


# Clears the input folder
def clear_input_folder(input_handle):
    path_to_folder = input_handle.get_path()
    list_dir = os.listdir(path_to_folder)
    for filename in list_dir:
        file_path = os.path.join(path_to_folder, filename)
        # If the element is a file
        if os.path.isfile(file_path) or os.path.islink(file_path):
            logger.info("deleting file: {}".format(file_path))
            os.unlink(file_path)
        # In case is a folder
        elif os.path.isdir(file_path):
            logger.info("deleting folder: {}".format(file_path))
            shutil.rmtree(file_path)
    logger.info("Cleared the input folder")


def retreive_bearer_token(endpoint, usr, pwd):
    headers = {
        "accept": "application/json",
        "Content-Type": "application/x-www-form-urlencoded",
    }
    data = {"grant_type": "", "username": usr, "password": pwd}
    response = requests.post(endpoint + "/token", headers=headers, data=data)
    if response.status_code >= 400:
        raise ValueError(
            "Cannot retreive access_token. Please check credentials and try again"
        )
    res_json = response.json()
    bearer_token = res_json["access_token"]
    # Bearer token for API usage
    bearer = "Bearer " + bearer_token
    return bearer


def check_response(response_obj):
    if response_obj.status_code == 200 or response_obj.status_code == 201:
        return True
    elif response_obj.status_code == 402:
        return "quota_exceeded"
    else:
        return False


def upload_files(doc, file_type, headers, input_handle, endpoint):
    with input_handle.get_download_stream(doc) as f:
        upload = {
            "file": (os.path.basename(doc), f)
        }  # To include just the filename use os.path.basename(doc)
        response = requests.post(
            endpoint
            + "/documents/?document_type="
            + file_type.lower()
            + "&language=xx",
            headers=headers,
            files=upload,
        )
        return response
